
from django.conf.urls import *


urlpatterns = patterns('liver.views',
        (r'^api/external/get_worker_job$',
        'api_external_get_worker_job',
        None, 'api-external-get-worker-job'),
        (r'^api/external/notify_worker_job_result$',
        'api_external_notify_worker_job_result',
        None, 'api-external-notify-worker-job-result'),
        ( r'^api/external/get_mo_to_delete$',
        'api_external_get_mo_to_delete',
        None, "api_external_get_mo_to_delete"),
        ( r'^api/external/get_mo$',
        'api_external_get_mo',
        None, "api_external_get_mo"),
        ( r'^api/external/update_recordings$',
        'api_external_update_recordings',
        None, "api_external_update_recordings"),


)



# -*- coding: utf-8 -*-
from south.utils import datetime_utils as datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'SourcesGroup'
        db.create_table(u'liver_sourcesgroup', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=5000)),
            ('external_id', self.gf('django.db.models.fields.CharField')(max_length=5000)),
            ('insertion_date', self.gf('django.db.models.fields.DateTimeField')()),
            ('modification_date', self.gf('django.db.models.fields.DateTimeField')(auto_now=True, auto_now_add=True, null=True, blank=True)),
            ('default_offset_start', self.gf('django.db.models.fields.IntegerField')(null=True, blank=True)),
            ('default_offset_end', self.gf('django.db.models.fields.IntegerField')(null=True, blank=True)),
            ('default_availability_window', self.gf('django.db.models.fields.IntegerField')(null=True, blank=True)),
        ))
        db.send_create_signal(u'liver', ['SourcesGroup'])

        # Adding model 'Source'
        db.create_table(u'liver_source', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=5000)),
            ('uri', self.gf('django.db.models.fields.CharField')(max_length=5000)),
            ('bitrate', self.gf('django.db.models.fields.IntegerField')(default=1000000)),
            ('insertion_date', self.gf('django.db.models.fields.DateTimeField')()),
            ('modification_date', self.gf('django.db.models.fields.DateTimeField')(auto_now=True, auto_now_add=True, null=True, blank=True)),
            ('sources_group', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['liver.SourcesGroup'], null=True, blank=True)),
        ))
        db.send_create_signal(u'liver', ['Source'])

        # Adding model 'Recorder'
        db.create_table(u'liver_recorder', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=5000)),
            ('token', self.gf('django.db.models.fields.CharField')(default='674bc67c-6429-11e4-83cd-61e6ff356173', max_length=5000)),
        ))
        db.send_create_signal(u'liver', ['Recorder'])

        # Adding model 'RecordingSource'
        db.create_table(u'liver_recordingsource', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('external_id', self.gf('django.db.models.fields.CharField')(default='', max_length=5000)),
            ('sources_group', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['liver.SourcesGroup'], null=True, blank=True)),
            ('insertion_date', self.gf('django.db.models.fields.DateTimeField')()),
            ('modification_date', self.gf('django.db.models.fields.DateTimeField')(auto_now=True, auto_now_add=True, null=True, blank=True)),
            ('enabled', self.gf('django.db.models.fields.BooleanField')(default=True)),
            ('enabled_since', self.gf('django.db.models.fields.DateTimeField')(null=True, blank=True)),
            ('enabled_until', self.gf('django.db.models.fields.DateTimeField')(default=None, null=True, blank=True)),
        ))
        db.send_create_signal(u'liver', ['RecordingSource'])

        # Adding model 'RecordingMetadata'
        db.create_table(u'liver_recordingmetadata', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('recording_source', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['liver.RecordingSource'])),
            ('key', self.gf('django.db.models.fields.CharField')(max_length=5000, blank=True)),
            ('value', self.gf('django.db.models.fields.CharField')(max_length=5000, blank=True)),
        ))
        db.send_create_signal(u'liver', ['RecordingMetadata'])

        # Adding model 'RecordingRule'
        db.create_table(u'liver_recordingrule', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('recording_source', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['liver.RecordingSource'])),
            ('metadata_key_filter', self.gf('django.db.models.fields.CharField')(max_length=5000, blank=True)),
            ('metadata_value_filter', self.gf('django.db.models.fields.CharField')(max_length=5000, blank=True)),
            ('offset_start', self.gf('django.db.models.fields.IntegerField')(null=True, blank=True)),
            ('offset_end', self.gf('django.db.models.fields.IntegerField')(null=True, blank=True)),
            ('availability_window', self.gf('django.db.models.fields.IntegerField')(null=True, blank=True)),
        ))
        db.send_create_signal(u'liver', ['RecordingRule'])

        # Adding model 'RecordingJob'
        db.create_table(u'liver_recordingjob', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('recording_source', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['liver.RecordingSource'], null=True, on_delete=models.SET_NULL, blank=True)),
            ('sources_group', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['liver.SourcesGroup'])),
            ('insertion_date', self.gf('django.db.models.fields.DateTimeField')()),
            ('modification_date', self.gf('django.db.models.fields.DateTimeField')(auto_now=True, auto_now_add=True, null=True, blank=True)),
            ('execution_date', self.gf('django.db.models.fields.DateTimeField')(null=True, blank=True)),
            ('completion_date', self.gf('django.db.models.fields.DateTimeField')(null=True, blank=True)),
            ('scheduled_start_date', self.gf('django.db.models.fields.DateTimeField')(null=True, blank=True)),
            ('scheduled_end_date', self.gf('django.db.models.fields.DateTimeField')(null=True, blank=True)),
            ('scheduled_duration', self.gf('django.db.models.fields.IntegerField')()),
            ('enabled', self.gf('django.db.models.fields.BooleanField')(default=True)),
            ('recorder', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['liver.Recorder'], null=True, on_delete=models.SET_NULL, blank=True)),
            ('result', self.gf('django.db.models.fields.CharField')(default='None', max_length=5000, null=True, blank=True)),
            ('status', self.gf('django.db.models.fields.CharField')(max_length=5000)),
        ))
        db.send_create_signal(u'liver', ['RecordingJob'])

        # Adding model 'RecordingJobMetadata'
        db.create_table(u'liver_recordingjobmetadata', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('recording_job', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['liver.RecordingJob'])),
            ('key', self.gf('django.db.models.fields.CharField')(max_length=5000, blank=True)),
            ('value', self.gf('django.db.models.fields.CharField')(max_length=5000, blank=True)),
        ))
        db.send_create_signal(u'liver', ['RecordingJobMetadata'])

        # Adding model 'Recording'
        db.create_table(u'liver_recording', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('recording_job', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['liver.RecordingJob'], null=True, on_delete=models.SET_NULL, blank=True)),
            ('recorder', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['liver.Recorder'], null=True, on_delete=models.SET_NULL, blank=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=5000, blank=True)),
            ('insertion_date', self.gf('django.db.models.fields.DateTimeField')()),
            ('modification_date', self.gf('django.db.models.fields.DateTimeField')(auto_now=True, auto_now_add=True, null=True, blank=True)),
            ('metadata_json', self.gf('django.db.models.fields.TextField')(max_length=5000, blank=True)),
            ('profiles_json', self.gf('django.db.models.fields.TextField')(max_length=5000, blank=True)),
            ('to_delete', self.gf('django.db.models.fields.BooleanField')(default=False)),
        ))
        db.send_create_signal(u'liver', ['Recording'])


    def backwards(self, orm):
        # Deleting model 'SourcesGroup'
        db.delete_table(u'liver_sourcesgroup')

        # Deleting model 'Source'
        db.delete_table(u'liver_source')

        # Deleting model 'Recorder'
        db.delete_table(u'liver_recorder')

        # Deleting model 'RecordingSource'
        db.delete_table(u'liver_recordingsource')

        # Deleting model 'RecordingMetadata'
        db.delete_table(u'liver_recordingmetadata')

        # Deleting model 'RecordingRule'
        db.delete_table(u'liver_recordingrule')

        # Deleting model 'RecordingJob'
        db.delete_table(u'liver_recordingjob')

        # Deleting model 'RecordingJobMetadata'
        db.delete_table(u'liver_recordingjobmetadata')

        # Deleting model 'Recording'
        db.delete_table(u'liver_recording')


    models = {
        u'liver.recorder': {
            'Meta': {'object_name': 'Recorder'},
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '5000'}),
            'token': ('django.db.models.fields.CharField', [], {'default': "'674bc67c-6429-11e4-83cd-61e6ff356173'", 'max_length': '5000'})
        },
        u'liver.recording': {
            'Meta': {'object_name': 'Recording'},
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'insertion_date': ('django.db.models.fields.DateTimeField', [], {}),
            'metadata_json': ('django.db.models.fields.TextField', [], {'max_length': '5000', 'blank': 'True'}),
            'modification_date': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'auto_now_add': 'True', 'null': 'True', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '5000', 'blank': 'True'}),
            'profiles_json': ('django.db.models.fields.TextField', [], {'max_length': '5000', 'blank': 'True'}),
            'recorder': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['liver.Recorder']", 'null': 'True', 'on_delete': 'models.SET_NULL', 'blank': 'True'}),
            'recording_job': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['liver.RecordingJob']", 'null': 'True', 'on_delete': 'models.SET_NULL', 'blank': 'True'}),
            'to_delete': ('django.db.models.fields.BooleanField', [], {'default': 'False'})
        },
        u'liver.recordingjob': {
            'Meta': {'object_name': 'RecordingJob'},
            'completion_date': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}),
            'enabled': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'execution_date': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'insertion_date': ('django.db.models.fields.DateTimeField', [], {}),
            'modification_date': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'auto_now_add': 'True', 'null': 'True', 'blank': 'True'}),
            'recorder': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['liver.Recorder']", 'null': 'True', 'on_delete': 'models.SET_NULL', 'blank': 'True'}),
            'recording_source': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['liver.RecordingSource']", 'null': 'True', 'on_delete': 'models.SET_NULL', 'blank': 'True'}),
            'result': ('django.db.models.fields.CharField', [], {'default': "'None'", 'max_length': '5000', 'null': 'True', 'blank': 'True'}),
            'scheduled_duration': ('django.db.models.fields.IntegerField', [], {}),
            'scheduled_end_date': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}),
            'scheduled_start_date': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}),
            'sources_group': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['liver.SourcesGroup']"}),
            'status': ('django.db.models.fields.CharField', [], {'max_length': '5000'})
        },
        u'liver.recordingjobmetadata': {
            'Meta': {'object_name': 'RecordingJobMetadata'},
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'key': ('django.db.models.fields.CharField', [], {'max_length': '5000', 'blank': 'True'}),
            'recording_job': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['liver.RecordingJob']"}),
            'value': ('django.db.models.fields.CharField', [], {'max_length': '5000', 'blank': 'True'})
        },
        u'liver.recordingmetadata': {
            'Meta': {'object_name': 'RecordingMetadata'},
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'key': ('django.db.models.fields.CharField', [], {'max_length': '5000', 'blank': 'True'}),
            'recording_source': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['liver.RecordingSource']"}),
            'value': ('django.db.models.fields.CharField', [], {'max_length': '5000', 'blank': 'True'})
        },
        u'liver.recordingrule': {
            'Meta': {'object_name': 'RecordingRule'},
            'availability_window': ('django.db.models.fields.IntegerField', [], {'null': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'metadata_key_filter': ('django.db.models.fields.CharField', [], {'max_length': '5000', 'blank': 'True'}),
            'metadata_value_filter': ('django.db.models.fields.CharField', [], {'max_length': '5000', 'blank': 'True'}),
            'offset_end': ('django.db.models.fields.IntegerField', [], {'null': 'True', 'blank': 'True'}),
            'offset_start': ('django.db.models.fields.IntegerField', [], {'null': 'True', 'blank': 'True'}),
            'recording_source': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['liver.RecordingSource']"})
        },
        u'liver.recordingsource': {
            'Meta': {'object_name': 'RecordingSource'},
            'enabled': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'enabled_since': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}),
            'enabled_until': ('django.db.models.fields.DateTimeField', [], {'default': 'None', 'null': 'True', 'blank': 'True'}),
            'external_id': ('django.db.models.fields.CharField', [], {'default': "''", 'max_length': '5000'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'insertion_date': ('django.db.models.fields.DateTimeField', [], {}),
            'modification_date': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'auto_now_add': 'True', 'null': 'True', 'blank': 'True'}),
            'sources_group': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['liver.SourcesGroup']", 'null': 'True', 'blank': 'True'})
        },
        u'liver.source': {
            'Meta': {'object_name': 'Source'},
            'bitrate': ('django.db.models.fields.IntegerField', [], {'default': '1000000'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'insertion_date': ('django.db.models.fields.DateTimeField', [], {}),
            'modification_date': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'auto_now_add': 'True', 'null': 'True', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '5000'}),
            'sources_group': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['liver.SourcesGroup']", 'null': 'True', 'blank': 'True'}),
            'uri': ('django.db.models.fields.CharField', [], {'max_length': '5000'})
        },
        u'liver.sourcesgroup': {
            'Meta': {'object_name': 'SourcesGroup'},
            'default_availability_window': ('django.db.models.fields.IntegerField', [], {'null': 'True', 'blank': 'True'}),
            'default_offset_end': ('django.db.models.fields.IntegerField', [], {'null': 'True', 'blank': 'True'}),
            'default_offset_start': ('django.db.models.fields.IntegerField', [], {'null': 'True', 'blank': 'True'}),
            'external_id': ('django.db.models.fields.CharField', [], {'max_length': '5000'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'insertion_date': ('django.db.models.fields.DateTimeField', [], {}),
            'modification_date': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'auto_now_add': 'True', 'null': 'True', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '5000'})
        }
    }

    complete_apps = ['liver']


# -*- coding:utf-8 -*-

# Author: Pablo Saavedra Rodinho
# Contact: pablo.saavedra@interoud.com

import time
import calendar
import dateutil.parser
import pytz

import  models

def from_dict_to_recording_source(o, in_list=False):


    # We accept also list of dicts, if list assumes a list of dicts
    if isinstance(o, list):
        for v in o:
            from_dict_to_recording_source(v)
    else: # Assumes a dict with a RecordingSource representation
        o["external_id"]
        rs_found=False
        for rs in models.RecordingSource.objects\
                .filter(external_id=o["external_id"]).iterator():
            rs_found=True
            rs.load_dict(o)
        if not rs_found:
            rs = models.RecordingSource()
            rs.load_dict(o)

def from_date_string_to_timestamp(date_txt):
    return int(calendar.timegm(dateutil.parser.parse(date_txt).utctimetuple()))

def from_date_to_timestamp(date):
    return int(calendar.timegm(date.astimezone(pytz.utc).utctimetuple()))

def get_model_fields(model):
    return model._meta.fields

def get_model_field_names(model):
    res = []
    for field in get_model_fields(model):
        f = field.name
        res.append(f)
    return res

def get_model_fields_values(modelobj):
    res = []
    for field in get_model_fields(modelobj):
        f = str(getattr(modelobj, field.name))
        res.append(f)
    return res





from models import *

import logging
logger = logging.getLogger("liver.admin")

from django import forms
from django import template

from django.contrib import admin
from django.core.exceptions import PermissionDenied
from django.contrib.admin import helpers
from django.contrib.admin.util import get_deleted_objects, model_ngettext
from django.db import router
from django.db.models import Q
from django.http import HttpResponseRedirect
from django.shortcuts import render_to_response
from django.template import RequestContext
from django.template.response import TemplateResponse
from django.utils.encoding import force_unicode
from django.utils.translation import ugettext_lazy, ugettext as _
from .forms import UploadFileForm

import utils

import datetime, time, pytz, calendar
import simplejson


def export_as_json(self, request, queryset):
    from django.http import HttpResponse
    response = HttpResponse(mimetype="text/javascript")
    response['Content-Disposition'] = 'attachment; filename=%s-%s-export-%s.json' % (
        __package__.lower(),
        queryset.model.__name__.lower(),
        datetime.datetime.now().strftime('%Y-%m-%d-%H-%M-%S'),
    )
    res_dict = []
    rs = RecordingSource.objects.all()
    for r in rs:
      res_dict.append(r.to_dict())
    res = simplejson.dump(res_dict, response, indent=4 )
    return response

def export_as_csv(self, request, queryset):
    from django.http import HttpResponse
    import csv

    # Create the HttpResponse object with the appropriate CSV header.
    response = HttpResponse(content_type='text/csv')
    response['Content-Disposition'] = 'attachment; filename=%s-%s-export-%s.csv' % (
        __package__.lower(),
        queryset.model.__name__.lower(),
        datetime.datetime.now().strftime('%Y-%m-%d-%H-%M-%S'),
    )

    writer = csv.writer(response)
    first_iter = True
    for o in queryset:
        if first_iter:
            headers = utils.get_model_field_names(o.__class__())
            writer.writerow(headers)
            first_iter = False
        values = utils.get_model_fields_values(o)
        writer.writerow(values)
    return response


def clone(modeladmin, request, queryset):
    for o in queryset:
        o.clone()
clone.short_description = _("Clone")

def import_from_json(modeladmin, request, queryset):
    print request
    opts = modeladmin.model._meta
    app_label = opts.app_label

    # Check that the user has delete permission for the actual model
    if not modeladmin.has_delete_permission(request):
        raise PermissionDenied

    using = router.db_for_write(modeladmin.model)

    # The user has already confirmed the deletion.
    # Do the deletion and return a None to display the change list view again.
    if request.POST.get('post'):
        print request.POST
    
        form = UploadFileForm(request.POST, request.FILES)
        if form.is_valid():
            # for chunk in request.FILES['file'].chunks():
            #     print chunk
            json = simplejson.load(request.FILES['file'])
            utils.from_dict_to_recording_source(json)
            return None
            modeladmin.message_user(request, _("Successfully imported.")
            , messages.SUCCESS)
        # Return None to display the change list page again.
        return None

    title = _("Import")
    form = UploadFileForm()

    context = {
        "title": title,
        "form": form,
        'queryset': queryset,
        "opts": opts,
        "app_label": app_label,
    }

    # Display the confirmation page

    return TemplateResponse(request, ["admin/%s/import_action.html" % app_label]
    , context, current_app=modeladmin.admin_site.name)


class RecordingRuleInLine(admin.TabularInline):
        model = RecordingRule
        extra = 1

class RecordingMetadataInLine(admin.TabularInline):
        model = RecordingMetadata
        extra = 1

class RecordingJobMetadataInLine(admin.TabularInline):
        model = RecordingJobMetadata
        extra = 1

class RecordingSourceAdmin(admin.ModelAdmin):
    actions = [
            export_as_json,
            # export_as_csv,
            import_from_json,
            clone,
    ]

    inlines = [
                RecordingRuleInLine,
                RecordingMetadataInLine,
    ]

    list_display = [
            'sources_group',
            # 'insertion_date',
            'modification_date',
            'enabled',
            'enabled_since',
            'enabled_until',
            'edit_html',
    ]

    list_editable = [
            'sources_group',
            'enabled',
            'enabled_since',
            'enabled_until',

    ]

    list_display_links = ['edit_html']

    list_per_page = 200

    def edit_html(self, queryset):
        return '''<a href="%s/">Edit</a>''' % queryset.id
    edit_html.short_description = ''
    edit_html.allow_tags = True



class RecordingJobAdmin(admin.ModelAdmin):
    ordering = ['-scheduled_start_date']

    actions = [
            "wait",
            "cancel",
            "success",
            "launch_now",
            clone,
    ]

    def launch_now(self, request, queryset):
        d = datetime.datetime.fromtimestamp(time.time(), pytz.UTC)
        for q in queryset:
            q.status="waiting"
            q.scheduled_start_date=d
            q.save()
    launch_now.short_description=_("Launch now")

    def wait(self, request, queryset):
        queryset.update(status="waiting")
    wait.short_description=_("Set to waiting")

    def cancel(self, request, queryset):
        queryset.update(status="cancelled")
    cancel.short_description=_("Set to cancelled")

    def success(self, request, queryset):
        queryset.update(status="successful")
    success.short_description=_("Set to successful")

    date_hierarchy = 'scheduled_start_date'

    list_per_page = 200

    search_fields = ['status','recordingjobmetadata__value' ]

    exclude = ["recording_source"]
    readonly_fields = [
            'insertion_date',
            'modification_date',
            'execution_date',
            'completion_date',
            'scheduled_end_date',
            'result',
    ]

    fieldsets = (
        (None, {
            'fields': (
                (
            'sources_group',
            'scheduled_start_date',
            'scheduled_end_date',
            'scheduled_duration',
            'enabled',
                ),

            )
        }),
        (_("Process"), {
            'fields': (
                (
            'status',
            'recorder',
                ),
                (
            'insertion_date',
            'modification_date',
            'execution_date',
            'completion_date',
                ),

            )
        }),

        (_("Log"), {
            'classes': ('collapse',),
            'fields': (
                ("result",
                ),
            )
        }),

    )

    list_display = [
      'pretty_name',
      'scheduled_start_date',
      'scheduled_end_date',
      'scheduled_duration',
      'insertion_date',
      'modification_date',
      'execution_date',
      'status',
    ]

    list_filter = [
            "enabled",
            "status",
            "recording_source",
            "recorder",
    ]

    inlines = [
        RecordingJobMetadataInLine,
    ]

class RecordingAdmin(admin.ModelAdmin):
    search_fields = ['name', 'metadata_json', 'profiles_json']

    ordering = ['-insertion_date']

    actions = [
            # clone,
    ]

    readonly_fields = [
            'name',
            'insertion_date',
            'modification_date',
            'recording_job',
            'profiles',
            'metadata',
    ]

    fieldsets = (
        (None, {
            'fields': (
                (
            'name',
            'insertion_date',
            'modification_date',
                ),

            )
        }),
        (_("Information"), {
            'fields': (
                (
            'profiles',
            'metadata',
                ),
            )
        }),

    )


    list_display = [
            'name',
            'insertion_date',
            'modification_date',
            'profiles',
            'metadata',
    ]

    list_per_page = 200

    def has_add_permission(self, request):
        return False

    def queryset(self, request):
        qs = super(RecordingAdmin, self).queryset(request)
        return qs.filter(Q(to_delete=False))


class SourceInLine(admin.TabularInline):
    model = Source
    fk_name = 'sources_group'
    extra = 0

class SourcesGroupAdmin(admin.ModelAdmin):
    actions = [
            clone,
    ]
    ordering = ['name']

    readonly_fields = [
            'insertion_date',
            'modification_date',
    ]

    fieldsets = (
        (None, {
            'fields': (
                (
            'name',
            'external_id',
                ),

            )
        }),
        (None, {
            'fields': (
                (
            'insertion_date',
            'modification_date',
                ),

            )
        }),
        (None, {
            'fields': (
                (
            'default_offset_start',
            'default_offset_end',
            'default_availability_window',
                ),

            )
        }),
    )

    inlines = [
      SourceInLine,
    ]


class RecorderAdmin(admin.ModelAdmin):
    ordering = ['name','token']


class ApplicationAdmin(admin.ModelAdmin):

    readonly_fields = [
            'id',
            'sync_time',
    ]

    list_editable = ['name','token', 'valid', 'valid_since','valid_until']

    list_display_links = ['edit_html']
    list_display = ('name', 'token', 'description',
            'valid', 'valid_since', 'valid_until',
            'modification_time', "edit_html")
    # list_filter = ['valid', 'source_host','enabled',
    #         ]
    search_fields = ['name', 'description','token',
            ]
    date_hierarchy = 'insertion_time'
    list_per_page = 200

    fieldsets = [
            (None,{
              'fields': [
                ('name','token'),
                ('valid','valid_since', 'valid_until','sync_time'),
                (),
            ]}),
            ('Other info', {
              'classes': ('collapse',),
              'fields': (
                ("description"),
              )
            }),
    ]

    def edit_html(self, queryset):
        return '''<a href="%s/">Edit</a>''' % queryset.id
    edit_html.short_description = ''
    edit_html.allow_tags = True



# admin.site.register(Source)
admin.site.register(SourcesGroup,SourcesGroupAdmin)
admin.site.register(Recorder,RecorderAdmin)
admin.site.register(RecordingSource,RecordingSourceAdmin)
admin.site.register(RecordingJob,RecordingJobAdmin)
admin.site.register(Recording,RecordingAdmin)
admin.site.register(Application,ApplicationAdmin)




# -*- coding: utf-8 -*-
from south.utils import datetime_utils as datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'Application'
        db.create_table(u'liver_application', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=250, blank=True)),
            ('description', self.gf('django.db.models.fields.TextField')(max_length=2500, blank=True)),
            ('token', self.gf('django.db.models.fields.CharField')(max_length=500, blank=True)),
            ('insertion_time', self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, null=True, db_index=True, blank=True)),
            ('modification_time', self.gf('django.db.models.fields.DateTimeField')(auto_now=True, auto_now_add=True, null=True, db_index=True, blank=True)),
            ('valid', self.gf('django.db.models.fields.BooleanField')(default=False)),
            ('valid_since', self.gf('django.db.models.fields.DateTimeField')(db_index=True, null=True, blank=True)),
            ('valid_until', self.gf('django.db.models.fields.DateTimeField')(default=None, null=True, db_index=True, blank=True)),
            ('sync_time', self.gf('django.db.models.fields.DateTimeField')(db_index=True, null=True, blank=True)),
        ))
        db.send_create_signal(u'liver', ['Application'])


    def backwards(self, orm):
        # Deleting model 'Application'
        db.delete_table(u'liver_application')


    models = {
        u'liver.application': {
            'Meta': {'object_name': 'Application'},
            'description': ('django.db.models.fields.TextField', [], {'max_length': '2500', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'insertion_time': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'null': 'True', 'db_index': 'True', 'blank': 'True'}),
            'modification_time': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'auto_now_add': 'True', 'null': 'True', 'db_index': 'True', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '250', 'blank': 'True'}),
            'sync_time': ('django.db.models.fields.DateTimeField', [], {'db_index': 'True', 'null': 'True', 'blank': 'True'}),
            'token': ('django.db.models.fields.CharField', [], {'max_length': '500', 'blank': 'True'}),
            'valid': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'valid_since': ('django.db.models.fields.DateTimeField', [], {'db_index': 'True', 'null': 'True', 'blank': 'True'}),
            'valid_until': ('django.db.models.fields.DateTimeField', [], {'default': 'None', 'null': 'True', 'db_index': 'True', 'blank': 'True'})
        },
        u'liver.recorder': {
            'Meta': {'object_name': 'Recorder'},
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '5000'}),
            'token': ('django.db.models.fields.CharField', [], {'default': "'3c2d8374-6ce2-11e4-83cd-8d34ee488137'", 'max_length': '5000'})
        },
        u'liver.recording': {
            'Meta': {'object_name': 'Recording'},
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'insertion_date': ('django.db.models.fields.DateTimeField', [], {}),
            'metadata_json': ('django.db.models.fields.TextField', [], {'max_length': '5000', 'blank': 'True'}),
            'modification_date': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'auto_now_add': 'True', 'null': 'True', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '5000', 'blank': 'True'}),
            'profiles_json': ('django.db.models.fields.TextField', [], {'max_length': '5000', 'blank': 'True'}),
            'recorder': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['liver.Recorder']", 'null': 'True', 'on_delete': 'models.SET_NULL', 'blank': 'True'}),
            'recording_job': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['liver.RecordingJob']", 'null': 'True', 'on_delete': 'models.SET_NULL', 'blank': 'True'}),
            'to_delete': ('django.db.models.fields.BooleanField', [], {'default': 'False'})
        },
        u'liver.recordingjob': {
            'Meta': {'object_name': 'RecordingJob'},
            'completion_date': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}),
            'enabled': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'execution_date': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'insertion_date': ('django.db.models.fields.DateTimeField', [], {}),
            'modification_date': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'auto_now_add': 'True', 'null': 'True', 'blank': 'True'}),
            'recorder': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['liver.Recorder']", 'null': 'True', 'on_delete': 'models.SET_NULL', 'blank': 'True'}),
            'recording_source': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['liver.RecordingSource']", 'null': 'True', 'on_delete': 'models.SET_NULL', 'blank': 'True'}),
            'result': ('django.db.models.fields.CharField', [], {'default': "'None'", 'max_length': '5000', 'null': 'True', 'blank': 'True'}),
            'scheduled_duration': ('django.db.models.fields.IntegerField', [], {}),
            'scheduled_end_date': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}),
            'scheduled_start_date': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}),
            'sources_group': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['liver.SourcesGroup']"}),
            'status': ('django.db.models.fields.CharField', [], {'max_length': '5000'})
        },
        u'liver.recordingjobmetadata': {
            'Meta': {'object_name': 'RecordingJobMetadata'},
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'key': ('django.db.models.fields.CharField', [], {'max_length': '5000', 'blank': 'True'}),
            'recording_job': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['liver.RecordingJob']"}),
            'value': ('django.db.models.fields.CharField', [], {'max_length': '5000', 'blank': 'True'})
        },
        u'liver.recordingmetadata': {
            'Meta': {'object_name': 'RecordingMetadata'},
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'key': ('django.db.models.fields.CharField', [], {'max_length': '5000', 'blank': 'True'}),
            'recording_source': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['liver.RecordingSource']"}),
            'value': ('django.db.models.fields.CharField', [], {'max_length': '5000', 'blank': 'True'})
        },
        u'liver.recordingrule': {
            'Meta': {'object_name': 'RecordingRule'},
            'availability_window': ('django.db.models.fields.IntegerField', [], {'null': 'True', 'blank': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'metadata_key_filter': ('django.db.models.fields.CharField', [], {'max_length': '5000', 'blank': 'True'}),
            'metadata_value_filter': ('django.db.models.fields.CharField', [], {'max_length': '5000', 'blank': 'True'}),
            'offset_end': ('django.db.models.fields.IntegerField', [], {'null': 'True', 'blank': 'True'}),
            'offset_start': ('django.db.models.fields.IntegerField', [], {'null': 'True', 'blank': 'True'}),
            'recording_source': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['liver.RecordingSource']"})
        },
        u'liver.recordingsource': {
            'Meta': {'object_name': 'RecordingSource'},
            'enabled': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'enabled_since': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}),
            'enabled_until': ('django.db.models.fields.DateTimeField', [], {'default': 'None', 'null': 'True', 'blank': 'True'}),
            'external_id': ('django.db.models.fields.CharField', [], {'default': "''", 'max_length': '5000'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'insertion_date': ('django.db.models.fields.DateTimeField', [], {}),
            'modification_date': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'auto_now_add': 'True', 'null': 'True', 'blank': 'True'}),
            'sources_group': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['liver.SourcesGroup']", 'null': 'True', 'blank': 'True'})
        },
        u'liver.source': {
            'Meta': {'object_name': 'Source'},
            'bitrate': ('django.db.models.fields.IntegerField', [], {'default': '1000000'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'insertion_date': ('django.db.models.fields.DateTimeField', [], {}),
            'modification_date': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'auto_now_add': 'True', 'null': 'True', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '5000'}),
            'sources_group': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['liver.SourcesGroup']", 'null': 'True', 'blank': 'True'}),
            'uri': ('django.db.models.fields.CharField', [], {'max_length': '5000'})
        },
        u'liver.sourcesgroup': {
            'Meta': {'object_name': 'SourcesGroup'},
            'default_availability_window': ('django.db.models.fields.IntegerField', [], {'null': 'True', 'blank': 'True'}),
            'default_offset_end': ('django.db.models.fields.IntegerField', [], {'null': 'True', 'blank': 'True'}),
            'default_offset_start': ('django.db.models.fields.IntegerField', [], {'null': 'True', 'blank': 'True'}),
            'external_id': ('django.db.models.fields.CharField', [], {'max_length': '5000'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'insertion_date': ('django.db.models.fields.DateTimeField', [], {}),
            'modification_date': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'auto_now_add': 'True', 'null': 'True', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '5000'})
        }
    }

    complete_apps = ['liver']